{% load static %}
<!DOCTYPE html>
<html>
<head>
    <title>{% block head_title %}{% endblock %}</title>
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap.min.css">
    <link rel="stylesheet" href="{% static "conversation/css/conversation.css" %}">
</head>
<body>

<div class="container" style="padding-top: 50px;">
    {% block main %}{% endblock %}
</div>

<script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/js/bootstrap.min.js"></script>
</body>
</html>